EmailAuth class
Class EmailAuth requires a auth.config.dart pacakge should follow the variable conventions as follows : var remoteServerConfig = {"server" : "serverUrl", "serverKey" : "Key generted from the email-auth-node package"} You can pass "remoteServerConfig" to the emailAuth instance.config() and generate them.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionName ↔ String
-
getter/setter pair
Methods
-
config(
Map< String, String> data) → Future<bool> - configuring the external server the Map should be of the pattern {"server" : "", "serverKey" : ""}
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendOtp(
{required String recipientMail, int otpLength = 6}) → Future< bool> - Takes care of sending the OTP to the server. returns a Boolean.
-
toString(
) → String -
A string representation of this object.
inherited
-
validateOtp(
{required String recipientMail, required String userOtp}) → bool - Boolean function to verify that the provided OTP and the user Email Ids, are all same.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited